==> ui-framework-elements-4.19.11.jar: gen/displays/templates/PropertyMold.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiTemplate from "alexandria-ui-elements/src/displays/components/Template";
import PropertyMoldNotifier from "alexandria-ui-elements/gen/displays/notifiers/TemplateNotifier";
import PropertyMoldRequester from "alexandria-ui-elements/gen/displays/requesters/TemplateRequester";
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class PropertyMold extends UiTemplate {

	constructor(props) {
		super(props);
		this.notifier = new PropertyMoldNotifier(this);
		this.requester = new PropertyMoldRequester(this);
	};

	render() {
	    const display = !this.state.visible ? {display:'none'} : undefined;
	    const className = "layout vertical center-justified" + (this.hiddenClass() !== "" ? " " + this.hiddenClass() : "");
		return(
			<UiBlock format="airBottom" layout="vertical" style={{...this.props.style,...display}}>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a187503373" format="body2 facetsAbsolute" mode="uppercase" value="">
				</UiText>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a362719149" layout="horizontal startjustified">
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a362719149.a_1814183202" format="h6" mode="normal">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a362719149.a_1492904171" format="h6" mode="normal" value=":  ">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a362719149.a_1813981299" format="h6 widgetType" mode="lowercase">
					</UiText>
				</UiBlock>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a312111403" format="body2" mode="normal" value="">
				</UiText>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a725418199" layout="horizontal">
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a725418199.a204433342" format="body2 valuesLabelFormat" mode="normal">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a725418199.a_1639754065" format="body2 widgetType" mode="normal" value=":  ">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a725418199.a2110766294" format="body2" mode="normal">
					</UiText>
				</UiBlock>
			</UiBlock>
		);
	}
}

export default withStyles(styles, { withTheme: true })(withSnackbar(PropertyMold));
DisplayFactory.register("PropertyMold", withStyles(styles, { withTheme: true })(withSnackbar(PropertyMold)));

==> ui-framework-elements-4.21.1.jar: gen/displays/templates/PropertyMold.js <==
import React from "react";
import { withStyles } from '@material-ui/core/styles';
import UiText from "alexandria-ui-elements/src/displays/components/Text";
import UiBlock from "alexandria-ui-elements/src/displays/components/Block";
import UiTemplate from "alexandria-ui-elements/src/displays/components/Template";
import PropertyMoldNotifier from "alexandria-ui-elements/gen/displays/notifiers/TemplateNotifier";
import PropertyMoldRequester from "alexandria-ui-elements/gen/displays/requesters/TemplateRequester";
import DisplayFactory from 'alexandria-ui-elements/src/displays/DisplayFactory';
import { withSnackbar } from 'notistack';

const styles = theme => ({});

class PropertyMold extends UiTemplate {

	constructor(props) {
		super(props);
		this.notifier = new PropertyMoldNotifier(this);
		this.requester = new PropertyMoldRequester(this);
	};

	render() {
	    const display = !this.state.visible ? {display:'none'} : undefined;
	    const className = "layout vertical center-justified" + (this.hiddenClass() !== "" ? " " + this.hiddenClass() : "");
		return(
			<UiBlock format="airBottom" layout="vertical" style={{...this.props.style,...display}}>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a187503373" format="body2 facetsAbsolute" mode="uppercase" value="">
				</UiText>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a2088122487" layout="horizontal startjustified">
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a2088122487.a_1020890974" format="h6" mode="normal">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a2088122487.a1053700699" format="h6" mode="normal" value=":  ">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a2088122487.a_1020689071" format="h6 widgetType" mode="lowercase">
					</UiText>
				</UiBlock>
				<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a312111403" format="body2" mode="normal" value="">
				</UiText>
				<UiBlock context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_554445479" layout="horizontal">
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_554445479.a_1075430336" format="body2 valuesLabelFormat" mode="normal">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_554445479.a966269489" format="body2 widgetType" mode="normal" value=":  ">
					</UiText>
					<UiText context={this._context.bind(this)} owner={this._owner.bind(this)} id="a_554445479.a1717739284" format="body2" mode="normal">
					</UiText>
				</UiBlock>
			</UiBlock>
		);
	}
}

export default withStyles(styles, { withTheme: true })(withSnackbar(PropertyMold));
DisplayFactory.register("PropertyMold", withStyles(styles, { withTheme: true })(withSnackbar(PropertyMold)));
